@@ -1,3 +1,8 @@
+//getaddrinfo is an extension (not C99)
+#if !defined(_WIN32) && !defined(__sun) && !defined(_POSIX_C_SOURCE)
+#define _POSIX_C_SOURCE 200112L
+#endif
+
 #include <Rinternals.h>
 #include <string.h>
 
@@ -7,11 +12,9 @@
 const char *inet_ntop(int af, const void *src, char *dst, socklen_t size);
 #else
 #include <sys/socket.h>
+#include <netinet/in.h>
 #include <netdb.h>
 #include <arpa/inet.h>
-#ifdef __FreeBSD__
-#include <netinet/in.h>
-#endif
 #endif
 
 SEXP R_nslookup(SEXP hostname) {
