@@ -9,7 +9,7 @@ test_that("Post text data", {
     "Cache-Control" = "no-cache",
     "User-Agent" = "A cow"
   )
-  req <- curl_fetch_memory("http://httpbin.org/post", handle = h)
+  req <- curl_fetch_memory(httpbin("post"), handle = h)
   res <- jsonlite::fromJSON(rawToChar(req$content))
 
   expect_equal(res$data, "moo=moomooo")
@@ -17,12 +17,12 @@ test_that("Post text data", {
   expect_equal(res$headers$`User-Agent`, "A cow")
 
   # Using connection interface
-  txt <- readLines(curl("http://httpbin.org/post", handle = h))
+  txt <- readLines(curl(httpbin("post"), handle = h))
   expect_equal(rawToChar(req$content), paste0(txt, "\n", collapse=""))
 
   # Using download interface
   tmp <- tempfile()
-  curl_download("http://httpbin.org/post", tmp, handle = h)
+  curl_download(httpbin("post"), tmp, handle = h)
   txt2 <- readLines(tmp)
   unlink(tmp)
   expect_equal(rawToChar(req$content), paste0(txt2, "\n", collapse=""))
@@ -32,7 +32,7 @@ test_that("Post text data", {
 test_that("Change headers", {
   # Default to application/url-encoded
   handle_setheaders(h, "User-Agent" = "Not a cow")
-  req <- curl_fetch_memory("http://httpbin.org/post", handle = h)
+  req <- curl_fetch_memory(httpbin("post"), handle = h)
   res <- jsonlite::fromJSON(rawToChar(req$content))
   expect_equal(res$form$moo, "moomooo")
   expect_equal(res$headers$`User-Agent`, "Not a cow")
@@ -43,7 +43,7 @@ test_that("Post JSON data", {
   handle_reset(h)
   handle_setopt(h, COPYPOSTFIELDS = jsonlite::toJSON(mtcars));
   handle_setheaders(h, "Content-Type" = "application/json")
-  req <- curl_fetch_memory("http://httpbin.org/post", handle = h)
+  req <- curl_fetch_memory(httpbin("post"), handle = h)
   output <- jsonlite::fromJSON(rawToChar(req$content))
 
   # Note that httpbin reoders columns alphabetically
@@ -60,7 +60,7 @@ test_that("Multipart form post", {
     description = form_file(system.file("DESCRIPTION")),
     logo = form_file(file.path(Sys.getenv("R_DOC_DIR"), "html/logo.jpg"), "image/jpeg")
   )
-  req <- curl_fetch_memory("http://httpbin.org/post", handle = h)
+  req <- curl_fetch_memory(httpbin("post"), handle = h)
   res <- jsonlite::fromJSON(rawToChar(req$content))
 
   expect_match(res$headers$`Content-Type`, "multipart")
